// Persistence of Vision Ray Tracer Scene Description File
// File: cam_spl.pov
// Vers: 3.6.1
// Desc: Example for camera-movement using Bezier-Splines
// Date: 18.02.03 (dd.mm.yy)
// Auth: Tim Nikias Wenclawiak - www.NoLights.de
// Last Update: 02.12.04 (dd.mm.yy)

//Required files:
// "bsplines.inc" - Include-File for BSplines

//Description:
// Just a simple setup for splines and then accessing it via
// BSpline_Pos() to position the camera.

//When viewing the scene with visualize-path set to off, you will notice
//blue spheres on the spline. These are the beginning and end points of
//sections. The camera will take the same amount of time for every section.
//Also note that due to the nature of Bezier-Spline-Calculations, the camera
//may look like its moving slower near beginning and end points.

//To overcome this, the bsplines.inc includes a BSpline2Linear-Macro, which
//will generate an amount of nodes evenly spread on the spline, and Linear_Pos
//may be used to calculate this. See BSplines.inc for details.

//This switch, if on, sets the scene to move the camera along the path, if set
//to off, will merely render a still-frame with the path visualized.
#declare Visualize_Path=off;

#include "bsplines.inc"

global_settings{assumed_gamma 1}
sky_sphere{pigment{gradient y color_map{[0 rgb <.6,.3,0>][1 rgb <0,0,.2>]}scale 2 translate -1}}


light_source{
 <100,200,-300> rgb 1
 area_light x*20,y*20,6,6 orient circular
 }

plane{<0,1,0>,0
 pigment{granite color_map{[0 rgb <.5,.4,.4>][1 rgb <.4,.2,.1>]}}
 }
sphere{y,1
 pigment{rgb x*.1}
 finish{
  reflection{0,1 falloff 2 exponent .9}
  specular .8 roughness .0001
  }
 }

//The Spline
#declare Cam_Spline=array[8]
 {
  <0,2,-5,0>,<1,0,0,0>,
  <5,3, 0,0>,<0,0,1,1>,
  <0,4, 6,0>,<-1,2,0,-.5>,
  <0,2,-5,0>,<4,0,0,0>
  }

#if (Visualize_Path=on)

camera{
 location BSpline_Pos(Cam_Spline,clock)
 look_at <0,1,0>
 }

#else
union{
 Show_BSpline(Cam_Spline,.1,150)
 pigment{rgb .5}
 finish{specular 1 roughness .001}
 }
union{
 Show_BNodes(Cam_Spline,.2)
 pigment{rgb z}
 finish{specular 1 roughness .001}
 }

camera{
 location <0,5,-10>
 look_at <0,1,0>
 }

#end